@@ -31,6 +31,20 @@ sub _populate {
         ]
     );
 
+  my @comments = $self->populate(
+        'Comment',
+        [
+            [ qw/ id  page_id body       /],
+            [     1,  1,      'comment 1' ],
+            [     2,  1,      'comment 2' ],
+            [     3,  2,      'comment 3' ],
+            [     4,  2,      'comment 4' ],
+            [     5,  1,      'comment 5' ],
+            [     6,  7,      'comment 6' ],
+            [     7, 11,      'comment 7' ],
+            [     8, 11,      'comment 8' ],
+        ]
+    );
 }
 __PACKAGE__->meta->make_immutable(inline_constructor => 0);
 1;
